
.. include:: ../README.rst

Table of Contents
=================

.. toctree::
    :maxdepth: 4
    :hidden:

    self

.. toctree::
    :caption: Python Examples

    examples

.. toctree::
    :caption: API Reference
    :maxdepth: 3

    state-of-things
    observers

.. toctree::
    :caption: Tutorial

.. toctree::
    :caption: Other Links

    Download from GitHub <https://github.com/mindwidgets/state-of-things/releases/latest>
    CircuitPython Reference Documentation <https://docs.circuitpython.org>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
